Coverage for test_elb.py: 0%

# Coverage for test_elb.py : 0%

## 8 statements 0 run 8 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | # -*- coding: utf-8 -*- import pytest from jungle import cli @pytest.mark.parametrize('elb_name', [ (''), ('*'), ('loadbalancer-01'), ('loadbalancer*'), ('dummy-lb'), ]) def test_elb_ls(runner, elb, elb_name): """test for elb ls""" result = runner.invoke(cli.cli, ['elb', 'ls', elb_name]) assert result.exit_code == 0 @pytest.mark.parametrize('elb_name', [ (''), ('*'), ('loadbalancer-01'), ('loadbalancer*'), ('dummy-lb'), ]) def test_elb_ls_with_l(runner, elb, elb_name): """test for elb ls -l""" result = runner.invoke(cli.cli, ['elb', 'ls', '-l', elb_name]) assert result.exit_code == 0